# KFinanceDataReader

## Install
```
pip install KFinanceDataReader
```

## 요약

한국의 주요 금융 데이터 추출을 위한 library

- 거시경제 지표 [ECOS](https://ecos.bok.or.kr/api/#/)
- 시장 지표 [KRX](https://data.krx.co.kr/)
- 기업 재무제표 지표 [DART](https://dart.fss.or.kr/)

## 장점

본 프로젝트는 다양한 source의 금융데이터를 활용하기 편한 형식으로 수집한다.
1. 데이터 수집 파라미터 형식의 통일
2. 추출된 데이터 형식의 통일



## 요구사항
- 거시경제 지표 추출을 위해 `ECOS API KEY`가 필요하다.
- 기업 재무제표 지표 추출을 위해 `DART API KEY`가 필요하다.